xhistogram: Fast, flexible, label-aware histograms for numpy and xarray
=======================================================================

|pypi| |conda forge| |tests| |linting| |codecov| |docs| |license|

For more information, including installation instructions, read the full
`xhistogram documentation`_.

.. _Pangeo: http://pangeo-data.github.io
.. _dask: http://dask.pydata.org
.. _xarray: http://xarray.pydata.org
.. _Arakawa Grids: https://en.wikipedia.org/wiki/Arakawa_grid
.. _xhistogram documentation: https://xhistogram.readthedocs.io/

.. |conda forge| image:: https://anaconda.org/conda-forge/xhistogram/badges/version.svg
   :target: https://anaconda.org/conda-forge/xhistogram
.. |DOI| image:: https://zenodo.org/badge/41581350.svg
   :target: https://zenodo.org/badge/latestdoi/41581350
.. |tests| image:: https://github.com/xgcm/xhistogram/actions/workflows/tests.yml/badge.svg
   :target: https://github.com/xgcm/xhistogram/actions/workflows/tests.yml
   :alt: travis-ci build status
.. |codecov| image:: https://codecov.io/github/xgcm/xhistogram/coverage.svg?branch=master
   :target: https://codecov.io/github/xgcm/xhistogram?branch=master
   :alt: code coverage
.. |pypi| image:: https://badge.fury.io/py/xhistogram.svg
   :target: https://badge.fury.io/py/xhistogram
   :alt: pypi package
.. |docs| image:: http://readthedocs.org/projects/xhistogram/badge/?version=latest
   :target: http://xhistogram.readthedocs.org/en/stable/?badge=latest
   :alt: documentation status
.. |linting| image:: https://github.com/xgcm/xhistogram/actions/workflows/linting.yml/badge.svg
   :target: https://github.com/xgcm/xhistogram/actions/workflows/linting.yml
   :alt: linting status
.. |license| image:: https://img.shields.io/github/license/mashape/apistatus.svg
   :target: https://github.com/xgcm/xhistogram
   :alt: license
